Learn R Programming

WaMaSim (version 1.0.0)

initiate.network: creates the initial network

Description

Creates the initial network that can be used with simulate_network.

Usage

initiate.network(inventory = 0, budget = Inf)

Arguments

inventory

if inventory is an integer it specifies the number of initial pipes, or alternatively it can be a data.frame containing the initial inventory of pipes.

budget

initial budget

Value

a state list