Learn R Programming

WaMaSim (version 1.0.0)

pipes.built.per.year: Calculate number of newly built pipes for each year

Description

The number of newly built pipes per year is calculated from a state list produced by simulate_network.

Usage

pipes.built.per.year(statelist)

Arguments

statelist

a state list

Value

vector containing the number of newly built pipes for each year