Learn R Programming

WaMaSim (version 1.0.0)

pipes.inservice.per.year: Returns the number of pipes in service for each year

Description

The number of pipes in service is calculated for every year based on a state list produced by simulate_network.

Usage

pipes.inservice.per.year(statelist)

Arguments

statelist

a state list

Value

vector containing the number of pipes in service